<?php

namespace Litecms\TicketBookingManagement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\TicketBookingManagement\Models\BookingManagement;

class BookingManagementPolicy
{

    /**
     * Determine if the given user can view the booking_management.
     *
     * @param UserPolicy $user
     * @param BookingManagement $booking_management
     *
     * @return bool
     */
    public function view(UserPolicy $user, BookingManagement $booking_management)
    {
        if ($user->canDo('ticket_booking_management.booking_management.view') && $user->isAdmin()) {
            return true;
        }

        return $booking_management->user_id == user_id() && $booking_management->user_type == user_type();
    }

    /**
     * Determine if the given user can create a booking_management.
     *
     * @param UserPolicy $user
     * @param BookingManagement $booking_management
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ticket_booking_management.booking_management.create');
    }

    /**
     * Determine if the given user can update the given booking_management.
     *
     * @param UserPolicy $user
     * @param BookingManagement $booking_management
     *
     * @return bool
     */
    public function update(UserPolicy $user, BookingManagement $booking_management)
    {
        if ($user->canDo('ticket_booking_management.booking_management.edit') && $user->isAdmin()) {
            return true;
        }

        return $booking_management->user_id == user_id() && $booking_management->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given booking_management.
     *
     * @param UserPolicy $user
     * @param BookingManagement $booking_management
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BookingManagement $booking_management)
    {
        return $booking_management->user_id == user_id() && $booking_management->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given booking_management.
     *
     * @param UserPolicy $user
     * @param BookingManagement $booking_management
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BookingManagement $booking_management)
    {
        if ($user->canDo('ticket_booking_management.booking_management.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given booking_management.
     *
     * @param UserPolicy $user
     * @param BookingManagement $booking_management
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BookingManagement $booking_management)
    {
        if ($user->canDo('ticket_booking_management.booking_management.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
