<?php

namespace Litecms\TicketBookingManagement\Providers;

use Illuminate\Support\ServiceProvider;

class TicketBookingManagementServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'ticket_booking_management');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'ticket_booking_management');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.ticket_booking_management', function ($app) {
            return $this->app->make('Litecms\TicketBookingManagement\TicketBookingManagement');
        });

                // Bind BookingManagement to repository
        $this->app->bind(
            'Litecms\TicketBookingManagement\Interfaces\BookingManagementRepositoryInterface',
            \Litecms\TicketBookingManagement\Repositories\Eloquent\BookingManagementRepository::class
        );

        $this->app->register(\Litecms\TicketBookingManagement\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\TicketBookingManagement\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\TicketBookingManagement\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.ticket_booking_management'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/ticket_booking_management.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/ticket_booking_management')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/ticket_booking_management')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
